
/********** DATA FOR TABLE A24 "Fiduciary deposits in Swiss Banks 1976-2008" *********/


clear
set more off
set memory 100m

use "data_fiduciary_accounts.dta", clear
/* This file contains the raw data on Swiss fiduciary deposits coming from the 1976-2008
editions of the Swiss National Bank's "Banks in Switzerland" */

/* lfidu = fiduciary deposits as recorded in "Banks in Switzerland" */


***************************************************************************************
*************************** I ---- Minor Adjustments to Raw Data ---- *****************
***************************************************************************************

* Fill some missing  country names
replace cn="United States minor Islands" if ccode=="UMI"
replace cn="St Helen" if ccode=="SHN"

* Update of the US/CHF exchange rate (end of period)
replace uschf_end=1.0637 if year==2008


******* Here, I deal with changes of perimeters (e.g. Monaco merged with France in 2006)

* Drop Faeroe Islands: part of Denmark and has 0 fiduciary liabilities throughout the period
drop if ifscode==816 

* Drop Greenland: part of Denmark and has 0 fiduciary liabilities except in 1995 (34). So I add 34 to Denmark in 1995 
drop if ifscode==326 
replace lfidu=69+34 if cn=="Denmark"&year==1995

* Drop Montenegro, add Montenegro to Serbia in 2007 and 2008 such that ifscode=942 is always Serbia + Montenegro
drop if ifscode==943
replace lfidu=141+4 if ifscode==942&year==2007
replace lfidu=110+16 if ifscode==942&year==2008
replace cn="Serbia and Montenegro" if ifscode==942

* Drop Canary Islands, add to Spain
drop if ifscode==185
replace lfidu=3896+17 if year==1984&ifscode==184
replace lfidu=3674+27 if year==1985&ifscode==184
replace lfidu=3089+34 if year==1986&ifscode==184
replace lfidu=3169+37 if year==1987&ifscode==184
replace lfidu=4051+51 if year==1988&ifscode==184
replace lfidu=5733+30 if year==1989&ifscode==184
replace lfidu=6600+27 if year==1990&ifscode==184
replace lfidu=6811+25 if year==1991&ifscode==184
replace lfidu=7031+27 if year==1992&ifscode==184
replace lfidu=5769+21 if year==1993&ifscode==184
replace lfidu=5551+14 if year==1994&ifscode==184
replace lfidu=4940+12 if year==1995&ifscode==184
replace lfidu=5797+12 if year==1996&ifscode==184
replace lfidu=6377+12 if year==1997&ifscode==184
replace lfidu=5843+8 if year==1998&ifscode==184


* Drop Guyane Franaise (merged with France in 2006), Runion and Antilles franaises (idem) and add fiduciary iabilities to France
drop if ifscode==333
drop if ifscode==696
drop if ifscode==888

* Monaco is merged with France in 2006, and this has a major impact on French deposits. 
* To correct for this, I estimate the theoretical amounts of deposits from Monaco in 2006, 2007 and 2008, 
* using the 2005 value and percent change of deposits from all small OFCs between 2005 and 2006 etc., 
* then substract it to France and add it to Monaco. 
* I also add to France the fiduciary deposits of Guadeloupe and Martinique (="Antilles franaises") 
* which are also merged with France in 2006

replace lfidu=2828 if cn=="Monaco"&year==2006
replace lfidu=3281 if cn=="Monaco"&year==2007
replace lfidu=2459 if cn=="Monaco"&year==2008
replace lfidu=8590+18+9 if cn=="France"&year==1984
replace lfidu=8174+8+6 if cn=="France"&year==1985
replace lfidu=7255+7+4 if cn=="France"&year==1986
replace lfidu=7410+10+4 if cn=="France"&year==1987
replace lfidu=9166+13+5 if cn=="France"&year==1988
replace lfidu=12832+76+5 if cn=="France"&year==1989
replace lfidu=14366+126+2+5 if cn=="France"&year==1990
replace lfidu=13839+85+3+5 if cn=="France"&year==1991
replace lfidu=15513+103+2+5 if cn=="France"&year==1992
replace lfidu=12185+121+2+4 if cn=="France"&year==1993
replace lfidu=11477+122+3+6 if cn=="France"&year==1994
replace lfidu=10445+173+2+6 if cn=="France"&year==1995
replace lfidu=10676+260+1+8 if cn=="France"&year==1996
replace lfidu=11603+42+1+8 if cn=="France"&year==1997
replace lfidu=10081+51+9 if cn=="France"&year==1998
replace lfidu=13198+50+2+14 if cn=="France"&year==1999
replace lfidu=13016+214+7 if cn=="France"&year==2000
replace lfidu=13222+46+19 if cn=="France"&year==2001
replace lfidu=9930+30+12 if cn=="France"&year==2002
replace lfidu=8846+19+17 if cn=="France"&year==2003
replace lfidu=7866+19+14 if cn=="France"&year==2004
replace lfidu=4756+28+8 if cn=="France"&year==2005
replace lfidu=7738-2828 if cn=="France"&year==2006
replace lfidu=8491-3281 if cn=="France"&year==2007
replace lfidu=6595-2459 if cn=="France"&year==2008



***************************************************************************************
*************************** II------- The case of Liechtenstein  **********************
***************************************************************************************


* Before 1984, Liechtenstein is considered as a foreign country (and it is the biggest foreign
* holder of deposits). After 1984, deposits from Liechenstein are considered to be Swiss deposits
* For the post 1984 period, I compute deposits from Liechtenstein as 45% of Swiss-owned fiduciary 
* deposits (45%=share of Liechtenstein deposits in (Liechtenstein + Switzerland) deposits in 1983)
* (NB: virtually 100% of the "Swiss-owned" fiduciary deposits may have foreign beneficial owners)

replace lfidu=16608 if ccode=="LIE"&year==1984 
replace lfidu=17615 if ccode=="LIE"&year==1985 
replace lfidu=16806 if ccode=="LIE"&year==1986 
replace lfidu=18039 if ccode=="LIE"&year==1987 
replace lfidu=22317 if ccode=="LIE"&year==1988 
replace lfidu=32439 if ccode=="LIE"&year==1989 
replace lfidu=35059 if ccode=="LIE"&year==1990 
replace lfidu=33880 if ccode=="LIE"&year==1991 
replace lfidu=33351 if ccode=="LIE"&year==1992 
replace lfidu=29153 if ccode=="LIE"&year==1993 
replace lfidu=26080 if ccode=="LIE"&year==1994 
replace lfidu=21077 if ccode=="LIE"&year==1995 
replace lfidu=24219 if ccode=="LIE"&year==1996 
replace lfidu=27642 if ccode=="LIE"&year==1997 
replace lfidu=26790 if ccode=="LIE"&year==1998 
replace lfidu=28659 if ccode=="LIE"&year==1999 
replace lfidu=34261 if ccode=="LIE"&year==2000
replace lfidu=31434 if ccode=="LIE"&year==2001
replace lfidu=24584 if ccode=="LIE"&year==2002
replace lfidu=22257 if ccode=="LIE"&year==2003
replace lfidu=22275 if ccode=="LIE"&year==2004
replace lfidu=27402 if ccode=="LIE"&year==2005
replace lfidu=33390 if ccode=="LIE"&year==2006
replace lfidu=36964 if ccode=="LIE"&year==2007
replace lfidu=30532 if ccode=="LIE"&year==2008



***************************************************************************************
*************************** III------- The case of Panama *****************************
***************************************************************************************


* Panama is the biggest depositor in 1984. But contrary to Lichtenstein we 
* don't have any direct info on Panama prior to 1984. 
* However we do have indirect info, because over 1976-1980 Panama is part of Central America and we
* have the total for Central America; and over 81-83 it is part of Caribbean and we have the total for
* Caribbean. Thus, I compute deposits in Panama as follows: 
* 1) 76-80: Panama = 80% of deposits from Central America
* 2) 1981 Panama = 66% of deposits from (Central America + Caribbean)
* 1982: Panama = 70% from (Central America + Caribbean)
* 1983: Panama = 74% from (Central America + Caribbean)
* (NB: in 1984 we observe Panama = 78% of deposits from (Central America + Caribbean); but in 1980
* 78% of (Central America + Caribbean) > Total Central America: this clearly indicates that there
* was an increasing trend for Panama.


replace lfidu=3484 if ccode=="PAN"&year==1976
replace lfidu=3718 if ccode=="PAN"&year==1977
replace lfidu=4068 if ccode=="PAN"&year==1978
replace lfidu=5585 if ccode=="PAN"&year==1979
replace lfidu=8452 if ccode=="PAN"&year==1980
replace lfidu=12367 if ccode=="PAN"&year==1981
replace lfidu=15292 if ccode=="PAN"&year==1982
replace lfidu=20347 if ccode=="PAN"&year==1983


* I substract Panama to Central America and Caribbean

replace lfidu=0.2*lfidu if ccode=="CenAm"&year<1981
replace lfidu=14319-12367 if ccode=="Caraib"&year==1981
replace lfidu= 19624-15292 if ccode=="Caraib"&year==1982
replace lfidu= 25341-20347 if ccode=="Caraib"&year==1983

* before 1984, Cayman, Bahamas, Bermuda, Netherland Antilles and smaller OFCs are included under the line "Caribbean"
* To deal with that, I assume that over 1976-1984, all deposits from the Caribbean are from tax havens (NB: in 1985, deposits from Caribbean
* non-OFC are almost 0). I add the value of Caribbean deposits to the Cayman Islands, and put Caribbean deps to 0 

replace lfidu=4112.1 if cn=="Cayman Islands"&year==1976
replace lfidu=3400.4 if cn=="Cayman Islands"&year==1977
replace lfidu=3327.4 if cn=="Cayman Islands"&year==1978
replace lfidu=3610.9 if cn=="Cayman Islands"&year==1979
replace lfidu=2920.5 if cn=="Cayman Islands"&year==1980
replace lfidu=1951.9 if cn=="Cayman Islands"&year==1981
replace lfidu=4332.1 if cn=="Cayman Islands"&year==1982
replace lfidu=4993.5 if cn=="Cayman Islands"&year==1983

replace lfidu=0 if ccode=="Caraib"&year<1985



***************************************************************************************
********************* IV ------ Bank-office level fiduciary deposits ******************
***************************************************************************************


* Statistics established following the "parent company level" consolidation principle exclude the
* deposits invested by a parent company in one of its subsidiaries (e.g., the deposits invested
* by UBS Switzerland in UBS Jersey). Now the two big banks invest most of the fiduciary deposits
* they manage in their foreign subsidiaries, so to have the totals right, it is crucial to
* correct this and express everything in terms of the right consolidation principle = "bank office level".
* Country breakdown are established following the "parent company level" consolidation principle,
* But we know the total fiduciary deposits according to the "bank office level" consolidation principle 
* So I multiply the deposits of each country by the aggregate ratio:
* Total deposits "bank office  level consolidation"/ Total deposits "parent company level conslidation"

* l = liability (= deposits)
* When no number specified = parent company level consolidation principle
* 2 = bank-office level consolidation principle
* When no currency specified = CHF
* dol = dollar

label variable lfidu "Fiduciary liabilities at the parent company level, millions of CHF"
gen lfidudol=lfidu/uschf_end
label variable lfidudol "Fiduciary liabilities at the parent company level, millions of US$ (end of p. exch)"
sort year

gen factor=0 /* (See MultiplicativeFactors.xls) */
replace factor=1.19345 if year==1976
replace factor=1.19346 if year==1977
replace factor=1.19344 if year==1978
replace factor=1.19346 if year==1979
replace factor=1.19346 if year==1980
replace factor=1.19346 if year==1981
replace factor=1.19345 if year==1982
replace factor=1.19345 if year==1983
replace factor=1.49533 if year==1984
replace factor=1.33770 if year==1985
replace factor=1.34592 if year==1986
replace factor=1.35913 if year==1987
replace factor=1.36417 if year==1988
replace factor=1.33423 if year==1989
replace factor=1.40106 if year==1990
replace factor=1.42873 if year==1991
replace factor=1.44338 if year==1992
replace factor=1.49598 if year==1993
replace factor=1.53212 if year==1994
replace factor=1.59081 if year==1995
replace factor=1.57913 if year==1996
replace factor=1.55232 if year==1997
replace factor=1.58033 if year==1998
replace factor=1.35169 if year==1999
replace factor=1.36379 if year==2000
replace factor=1.39325 if year==2001
replace factor=1.41946 if year==2002
replace factor=1.38324 if year==2003
replace factor=1.41743 if year==2004
replace factor=1.46754 if year==2005
replace factor=1.50959 if year==2006
replace factor=1.59886 if year==2007
replace factor=1.63574 if year==2008

label variable factor "Aggregate scale-up factor for deposits, from Parent Company to Bank Office level"
gen lfidu2=lfidu*factor
label variable lfidu2 "Fiduciary liabilities at the bank office level, millions of CHF"
gen lfidu2dol=lfidu2/uschf_end
label variable lfidu2dol "Fiduciary liabilities at the bank office level, millions of US$ (end of p. exch)"
drop factor uschf_end


***************************************************************************************
************************* V----- Definition of Geographical areas *********************
***************************************************************************************


/* Euro area members as of December 31st, 2010 */

/* 11 initial members of the euro area */
gen euro11=0
#delimit;
replace euro11=1 if cn=="Austria"|cn=="Belgium"|cn=="Finland"|cn=="France"|
cn=="Germany"|cn=="Ireland"|cn=="Italy"|cn=="Luxembourg"|cn=="Netherlands"|
cn=="Portugal"|cn=="Spain";
/* All members as of July, 2011 */
gen euro17=euro11;
replace euro17=1 if cn=="Cyprus"|cn=="Estonia"|cn=="Greece"|cn=="Malta"|
cn=="Slovak Republic"|cn=="Slovenia";
#delimit cr
/* All members as of December 31st, 2010 */
gene euro16=euro17
replace euro16=0 if cn=="Estonia"
drop euro11 euro17

/* Set of rich countries */

gen rich=0
replace rich=1 if ifscode<200|euro16==1
replace rich=0 if cn=="San Marino"|cn=="South Africa"|cn=="Turkey"|cn=="Vatican"
gen developing=0
replace developing=1 if rich==0

/* Set of offshore financial centers where sham wealth-holding entities are incorporated */

* NB: in principle sham entities can be created almost anywhere, but I stick to conventional
* lists of tax havens (with the exception of Venezuela, see below)
* + I include the islands with anormously high fiduciary deposits (e.g. "British overseas territories" etc.)


gen ofc=0
#delimit;
replace ofc=1 if cn=="San Marino"|cn=="Luxembourg"|cn=="Malta"|cn=="Costa Rica"|cn=="Panama"|cn=="Uruguay"
|cn=="Antigua and Barbuda"|cn=="Bahamas, The"|cn=="Bermuda"|cn=="Aruba"|cn=="Barbados"|cn=="Dominica"|cn=="Grenada"
|cn=="Belize"|cn=="Netherlands Antilles"|cn=="St. Kitts and Nevis"|cn=="St. Lucia"|cn=="St. Vincent and the Grenadines"
|cn=="British Antilles"|cn=="British Overseas Territories"|cn=="Cayman Islands"|cn=="Turks and Caicos Islands"|cn=="Bahrain"
|cn=="Cyprus"|cn=="Lebanon"|cn=="Hong Kong, China"|cn=="Macao, China"|cn=="Malaysia"|cn=="Palau"|cn=="Singapore"|cn=="Liberia"
|cn=="Mauritius"|cn=="Seychelles"|cn=="Gibraltar"|cn=="Nauru"|cn=="Vanuatu"|cn=="Samoa"|cn=="Marshall Islands"|cn=="Andorra"
|cn=="Guernesey"|cn=="Isle of Man"|cn=="Jersey"|cn=="Monaco";
replace ofc=1 if cn=="Liechtenstein";
#delimit cr

/* Between 2004 and 2005, the fiduciary deposits from Venezuela rise spectacularly (barring this episode, 
no particular evolution is observed for this country over more than 30 years of data). The most likeky 
cause is a transfer of EU deposits to a sham Venezuelian corporation. We want to include them in the 
"deposits from OFCs" category. After 2005, therefore, I subtract these likeky EU holdings from Venezuela 
and add them to Uruguay, which is considered to be an OFC in my list (contrary to Venezuela) */

replace lfidu2dol=2500 if cn=="Venezuela, RB"&year>=2005
replace lfidu2dol=lfidu2dol+8434.8 if cn=="Uruguay"&year==2005
replace lfidu2dol=lfidu2dol+5111.4 if cn=="Uruguay"&year==2006
replace lfidu2dol=lfidu2dol+9373.2 if cn=="Uruguay"&year==2007
replace lfidu2dol=lfidu2dol+4752.2 if cn=="Uruguay"&year==2008



/* Continents */

gen north_am=0
replace north_am=1 if cn=="United States"|cn=="Canada"

gen latin_am=0
replace latin_am=1 if ifscode>=200&ifscode<300
replace latin_am=1 if ccode=="OthSA"|ccode=="CenAm"

gen caribbean=0
replace caribbean=1 if ifscode>=300&ifscode<400
replace caribbean=1 if cn=="Cuba"
replace caribbean=1 if ccode=="Caraib"

gen middle_east=0
replace middle_east=1 if ifscode>=400&ifscode<500
replace middle_east=0 if cn=="Cyprus" /* euro area */
/* Memo: the "Middle East" aggregate in SNB data prior to 1984 excludes Lebanon, Israel, and West Bank and Gaza, but includes Brunei */
replace middle_east=1 if ccode=="OthME"

gen asia=0
replace asia=1 if ifscode>=500&ifscode<600
replace asia=1 if cn=="Australia"|cn=="New Zealand"|cn=="Japan"|cn=="China"|cn=="Korea, Dem. Rep."
replace asia=1 if cn=="Micronesia, Fed. Sts."|cn=="Mongolia"|cn=="Tuvalu"|cn=="French Polynesia"
replace asia=1 if cn=="Vanuatu"|cn=="Tonga"|cn=="Papua New Guinea"|cn=="Nauru"|cn=="United States minor Islands"
replace asia=1 if cn=="New Caledonia"|cn=="Wallis et Futuna"|cn=="St Helen"|cn=="Kiribati"|cn=="Solomon Islands"|cn=="Fiji"
replace asia=1 if ccode=="OthAs"|ccode=="AusNZ"
replace asia=1 if cn=="Ouzbekistan"|cn=="Kyrgyz Republic"|cn=="Turkmenistan"|cn=="Tajikistan"|cn=="Uzbekistan"
/* Countries at the frontier between Europe and Asia: */
replace asia=1 if cn=="Georgia"|cn=="Russian Federation"|cn=="Armenia"|cn=="Azerbaijan"|cn=="Kazakhstan"|cn=="Turkey"|cn=="USSR"

gen africa=0
replace africa=1 if (ifscode>=600&ifscode<700)|(ifscode>=700&ifscode<800)
replace africa=1 if cn=="South Africa"
replace africa=1 if ccode=="OthAf"|ccode=="NorAf"

gen europe=0
replace europe=1 if ifscode<200&north_am!=1&asia!=1&africa!=1&cn!="Turkey"
replace europe=1 if euro16==1
#delimit;
replace europe=1 if cn=="Croatia"|cn=="Estonia"|cn=="Ukraine"|cn=="Moldova"
|cn=="Serbia and Montenegro"|cn=="Czech Republic"|cn=="Romania"|cn=="Belarus"|cn=="Bosnia and Herzegovina"
|cn=="Bulgaria"|cn=="Lithuania"|cn=="Latvia"|
cn=="Albania"|cn=="Poland"|cn=="Hungary"|cn=="Macedonia, FYR";
#delimit cr
replace europe=1 if cn=="German Democratic Republic"|ccode=="EasEU"|cn=="Tchecoslovakia"
replace europe=1 if ccode=="NwFin"|ccode=="OtWEU"|cn=="Yugoslavia"


/* Drop offshore financial centers from continents and groups */
replace rich=0 if rich==1&ofc==1
replace developing=0 if developing==1&ofc==1
replace europe=0 if europe==1&ofc==1
replace middle_east=0 if middle_east==1&ofc==1
replace africa=0 if africa==1&ofc==1
replace asia=0 if asia==1&ofc==1
replace caribbean=0 if caribbean==1&ofc==1
replace latin_am=0 if latin_am==1&ofc==1


/* Define labels */

gen continent=1*africa+2*europe+3*middle_east+4*asia+5*caribbean+6*latin_am+7*north_am+8*ofc
label variable continent "Continent"
label define continentlbl 1 "Africa" 2 "Europe" 3 "Middle East" 4 "Asia" 5 "Caribbean" 6 "Latin and South America" 7 "North America" 8 "OFC"
label values continent continentlbl


gen group=1*rich+2*developing+3*ofc
label variable group "Country groups"
label define grouplbl 1 "Rich" 2 "Developing" 3 "OFC"
label values group grouplbl

/* Country names for aggregates prior to 1984 */
replace cn="Eastern Europe" if ccode=="EasEU"
replace cn="North Africa" if ccode=="NorAf"
replace cn="Other Middle East" if ccode=="OthME"
replace cn="Caribbean" if ccode=="Caraib"
replace cn="Other Western Europe" if ccode=="OtWEU"
replace cn="Other South America" if ccode=="OthSA"
replace cn="Other Asia" if ccode=="OthAs"
replace cn="Other Africa" if ccode=="OthAf"
replace cn="Australia and New Z" if ccode=="AusNZ"
replace cn="Central America" if ccode=="CenAm"
replace cn="Norway and Finland" if ccode=="NwFin"



***************************************************************************************
******************************  VI ----Tables  ****************************************
**************************************************************************************


* table year, c(sum lfidu sum lfidudol sum lfidu2 sum lfidu2dol) format(%6.0f)

* Appendix Tables A22-A24 
table year group, c(sum lfidu2dol) format(%6.0f) col
table year continent, c(sum lfidu2dol) format(%6.0f) col
table year if euro16==1, c(sum lfidu2dol) format(%6.0f)












